@@ -55,6 +55,7 @@ from box import Box
 
 # Related modules
 from . import common
+from . import data
 
 def normalize_prefix(pfx: typing.Union[str,Box]) -> Box:
   if not pfx:
@@ -68,6 +69,13 @@ def normalize_prefix(pfx: typing.Union[str,Box]) -> Box:
 
   return pfx
 
+def rebuild_prefix(pfx: typing.Union[dict,Box]) -> dict:
+  out_pfx = {}
+  for af in ('ipv4','ipv6'):
+    if af in pfx:
+      out_pfx[af] = str(pfx[af])
+  return out_pfx
+
 def setup_pools(addr_pools: typing.Optional[Box] = None, defaults: typing.Optional[Box] = None) -> Box:
   addrs = addr_pools or Box({},default_box=True)
   defaults = defaults or Box({},default_box=True)
@@ -246,7 +254,7 @@ def get(pools: Box, pool_list: typing.Optional[typing.List[str]] = None, n: typi
     return {}                             # pragma: no cover -- can't figure out how to get here
 
 def setup(topo: Box, defaults: Box) -> None:
-  common.null_to_string(topo.addressing)
+  data.null_to_string(topo.addressing)
   addrs = setup_pools(defaults.addressing + topo.addressing,defaults)
 
   common.print_verbose("Addressing\n=================")
