@@ -9,6 +9,7 @@ from box import Box
 
 # Related modules
 from .. import common
+from .. import data
 from .. import addressing
 from . import devices
 
@@ -50,7 +51,7 @@ def adjust_link_list(links: list, nodes: Box) -> list:
   for l in links:
     if isinstance(l,dict) and IFATTR in l:               # a dictionary with 'interfaces' element
       l = Box(l,default_box=True,box_dots=True)
-      common.must_be_list(l,IFATTR,f'link[{link_cnt}]')  # ... check it's a list and move on
+      data.must_be_list(l,IFATTR,f'link[{link_cnt}]')    # ... check it's a list and move on
       l[IFATTR] = adjust_interface_list(l[IFATTR],l,nodes)
       link_list.append(l)
     elif isinstance(l,dict):                             # a dictionary without 'interfaces' element
@@ -114,9 +115,6 @@ def get_link_base_attributes(defaults: Box) -> set:
   return get_link_full_attributes(defaults) - set(no_propagate)
 
 def add_node_interface(node: Box, ifdata: Box, defaults: Box) -> Box:
-  if not 'interfaces' in node:
-    node.interfaces = []
-
   ifindex_offset = devices.get_device_attribute(node,'ifindex_offset',defaults)
   if ifindex_offset is None:
     ifindex_offset = 1
@@ -126,7 +124,7 @@ def add_node_interface(node: Box, ifdata: Box, defaults: Box) -> Box:
   ifname_format = devices.get_device_attribute(node,'interface_name',defaults)
 
   ifdata.ifindex = ifindex
-  if ifname_format:
+  if ifname_format and not 'ifname' in ifdata:
     ifdata.ifname = ifname_format % ifindex
 
   pdata = devices.get_provider_data(node,defaults).get('interface',{})
@@ -270,6 +268,8 @@ def augment_link_prefix(link: Box,pools: typing.List[str],addr_pools: Box) -> di
     pools = [ link.get('role') ] + pools
   if 'prefix' in link:
     pfx_list = addressing.parse_prefix(link.prefix)
+    if isinstance(link.prefix,str):
+      link.prefix = addressing.rebuild_prefix(pfx_list)
   elif 'unnumbered' in link:
     pfx_list = Box({ 'unnumbered': True })
   else:
@@ -322,7 +322,9 @@ def augment_lan_link(link: Box, addr_pools: Box, ndict: dict, defaults: Box) ->
       ifaddr.name = link.get("name") or (node + " -> [" + ",".join(list(n_list))+"]")
 
     ifdata = interface_data(link=link,link_attr=link_attr_base,ifdata=ifaddr)
-    interfaces.append({ 'node': node, 'data': add_node_interface(ndict[node],ifdata,defaults) })
+    node_intf = add_node_interface(ndict[node],ifdata,defaults)
+    value.ifindex = node_intf.ifindex
+    interfaces.append({ 'node': node, 'data':  node_intf })
 
     link_cnt = link_cnt + 1
 
@@ -343,17 +345,24 @@ def augment_p2p_link(link: Box, addr_pools: Box, ndict: dict, defaults: Box) ->
   link_attr_base = get_link_base_attributes(defaults)
   if not defaults:      # pragma: no cover (almost impossible to get there)
     defaults = Box({})
+  if common.DEBUG:     # pragma: no cover (debugging)
+    print(f'\nProcess P2P link {link}')
   pfx_list = augment_link_prefix(link,['p2p','lan'],addr_pools)
 
   end_names = ['left','right']
   link_nodes: typing.List[Box] = []
   interfaces: typing.List[Box] = []
 
-  intf_cnt = 0
-  for value in sorted(link[IFATTR],key=lambda v: v.node):
+  if len(link[IFATTR]) > len(end_names): # pragma: no cover (this error is reported earlier)
+    common.fatal(f"Internal error: Too many nodes specified on a P2P link {link}",'links')
+    return None
+
+  link[IFATTR] = sorted(link[IFATTR],key=lambda v: v.node)       # Keep nodes sorted in alphabetic order for historic reasons
+  value: Box
+  for intf_cnt,value in enumerate(link[IFATTR]):
     node = value.node
     ecount = len(link_nodes)
-    ifaddr = Box({},default_box=True)
+    ifaddr = Box({},default_box=True,box_dots=True)
     if link.get('unnumbered',None):
       ifaddr.unnumbered = True
 
@@ -376,31 +385,21 @@ def augment_p2p_link(link: Box, addr_pools: Box, ndict: dict, defaults: Box) ->
 
     ifaddr = ifaddr + value
     ifaddr.pop('node',None)               # Remove the 'node' attribute from interface data -- now we know where it belongs
-    link[IFATTR][intf_cnt] = value
-    intf_cnt = intf_cnt + 1
+#    link[IFATTR][intf_cnt] = value
     link_nodes.append(Box({ 'name': node, 'link': value, 'ifaddr': ifaddr }))
 
-  if len(link_nodes) > len(end_names): # pragma: no cover (this error is reported earlier)
-    common.fatal(f"Internal error: Too many nodes specified on a P2P link {link}",'links')
-    return None
-
-  for i in range(0,len(link_nodes)):
-    node = link_nodes[i].name
-    ifdata = interface_data(link=link,link_attr=link_attr_base,ifdata=link_nodes[i].ifaddr)
-    ifdata.name = link.get("name") or (link_nodes[i].name + " -> " + link_nodes[1-i].name)
+    ifdata = interface_data(link=link,link_attr=link_attr_base,ifdata=ifaddr)
+    if 'bridge' in link:
+      ifdata.bridge = link.bridge
+    ifdata.name = link.get("name") or (link[IFATTR][intf_cnt].node + " -> " + link[IFATTR][1-intf_cnt].node)
     dict_2_update = add_node_interface(ndict[node],ifdata,defaults)
+    value.ifindex = dict_2_update.ifindex
     interfaces.append(dict_2_update)
 
   if not 'name' in link:
     link.name = link_nodes[0].name + " - " + link_nodes[1].name
 
   for i in range(0,2):
-    if 'bridge' in link:
-      interfaces[i].bridge = link.bridge
-    else:
-      interfaces[i].remote_id = ndict[link_nodes[1-i].name].id
-      interfaces[i].remote_ifindex = interfaces[1-i].ifindex
-
     link[end_names[i]] = { 'node': link_nodes[i]['name'],'ifname': interfaces[i].get('ifname') }
 
     remote = link_nodes[1-i].name
@@ -428,23 +427,26 @@ def check_link_attributes(data: Box, nodes: dict, valid: set) -> bool:
 def set_link_type_role(link: Box, pools: Box, nodes: Box) -> None:
   node_cnt = len(link[IFATTR])      # Set the number of attached nodes (used in many places further on)
   link['node_count'] = node_cnt
+
+  host_count = 0                    # Count the number of hosts attached to the link
+  for ifdata in link[IFATTR]:
+    if nodes[ifdata.node].get('role','') == 'host':
+      host_count = host_count + 1
+
+  if host_count > 0:                # If we have hosts and a single router attached to a non-VLAN link, set link role to 'stub'
+    link.host_count = host_count    # ... VLAN case will be set in the VLAN module
+    if not 'role' in link and host_count == node_cnt - 1 and not 'vlan_name' in link:
+      link.role = 'stub'
+
   if 'type' in link:                # Link type already set, nothing to do
     return
 
   link.type = 'lan' if node_cnt > 2 else 'p2p' if node_cnt == 2 else 'stub'     # Set link type based on number of attached nodes
 
-  host_count = 0
-  for ifdata in link[IFATTR]:
-    if nodes[ifdata.node].get('role','') == 'host':
-      host_count = host_count + 1
-
   if host_count > 0:
     link.type = 'lan'
-    link.host_count = host_count
-    if not 'role' in link:
-      link.role = 'stub'
 
-  return 
+  return
 
 def check_link_type(data: Box) -> bool:
   node_cnt = data.get('node_count') # link_node_count(data,nodes)
@@ -452,7 +454,7 @@ def check_link_type(data: Box) -> bool:
 
   if 'mtu' in data and not isinstance(data.mtu,int): # pragma: no cover
     common.error(f'MTU parameter should be an integer: {data}',common.IncorrectValue,'links')
-    
+
   if not link_type: # pragma: no cover (shouldn't get here)
     common.fatal('Internal error: link type still undefined in check_link_type: %s' % data,'links')
     return False
@@ -469,7 +471,7 @@ def check_link_type(data: Box) -> bool:
     common.error('Point-to-point link needs exactly two nodes: %s' % data,common.IncorrectValue,'links')
     return False
 
-  if not link_type in [ 'stub','p2p','lan']:
+  if not link_type in [ 'stub','p2p','lan','vlan_member']:
     common.error('Invalid link type %s: %s' % (link_type,data),common.IncorrectValue,'links')
     return False
   return True
@@ -542,12 +544,20 @@ def set_node_af(nodes: Box) -> None:
           n.af[af] = True
           continue
 
+def set_linkindex(topology: Box) -> None:
+  if not 'links' in topology:
+    return
+
+  linkindex = topology.defaults.get('link_index',1)
+  for link in topology.links:
+    link.linkindex = linkindex
+    linkindex = linkindex + 1
+
 def transform(link_list: typing.Optional[Box], defaults: Box, nodes: Box, pools: Box) -> typing.Optional[Box]:
   if not link_list:
     return None
 
   link_attr_full = get_link_full_attributes(defaults)
-  linkindex = defaults.get('link_index',1)
 
   for link in link_list:
     if not check_link_attributes(data=link,nodes=nodes,valid=link_attr_full):
@@ -557,21 +567,18 @@ def transform(link_list: typing.Optional[Box], defaults: Box, nodes: Box, pools:
     if not check_link_type(data=link):
       continue
 
-    link.linkindex = linkindex
     if link.type == 'p2p':
       augment_p2p_link(link,pools,nodes,defaults=defaults)
     else:
       if not 'bridge' in link:
-        br = defaults.name if len(defaults.name)<12 and linkindex<100 else 'netsim-br'
-        link['bridge'] = "%s_%d" % (br,linkindex) # max 15 chars on Linux
-      elif len(link['bridge'])>15:
+        link['bridge'] = "%s_%d" % (defaults.name[0:10],link.linkindex) # max 15 chars on Linux
+      elif len(link['bridge']) > 15:
         common.error(
             f'Bridge name {link["bridge"]} has more than 15 characters',
             common.IncorrectValue,
             'interfaces')
       augment_lan_link(link,pools,nodes,defaults=defaults)
 
-    linkindex = linkindex + 1
     set_default_gateway(link,nodes)
 
   interface_feature_check(nodes,defaults)
