@@ -41,8 +41,11 @@ def create_node_dict(nodes: Box) -> Box:
     elif not isinstance(ndata,dict):
       common.error(f'Node data for node {name} must be a dictionary')
       node_dict[name] = { 'name': name, 'extra': ndata }
+      ndata = node_dict[name]
     else:
       ndata['name'] = name
+
+    ndata.interfaces = ndata.interfaces or []   # Make sure node.interfaces is always defined
     node_dict[name] = ndata
 
   common.exit_on_error()
@@ -63,6 +66,11 @@ def augment_mgmt_if(node: Box, defaults: Box, addrs: typing.Optional[Box]) -> No
       mgmt_if = ifname_format % (ifindex_offset - 1)
     node.mgmt.ifname = mgmt_if
 
+  # If the mgmt ipaddress is statically set (IPv4/IPv6)
+  # skip the address set
+  if 'ipv4' in node.mgmt or 'ipv6' in node.mgmt:
+    return
+
   if addrs:
     for af in 'ipv4','ipv6':
       pfx = af + '_pfx'
@@ -88,7 +96,7 @@ def augment_node_provider_data(topology: Box) -> None:
     common.fatal('Device defaults (defaults.devices) are missing')
 
   for name,n in topology.nodes.items():
-    if not n.device:
+    if 'device' not in n:
       n.device = topology.defaults.device
 
     if not n.device:
