@@ -6,6 +6,10 @@
 import sys
 import importlib
 import argparse
+import os
+import shutil
+import typing
+
 from box import Box
 
 from . import usage
@@ -29,13 +33,34 @@ def common_parse_args(debugging: bool = False) -> argparse.ArgumentParser:
 
 def topology_parse_args() -> argparse.ArgumentParser:
   parser = argparse.ArgumentParser(description='Common topology arguments',add_help=False)
-  parser.add_argument('--defaults', dest='defaults', action='store', default='topology-defaults.yml',
+  parser.add_argument('--defaults', dest='defaults', action='store',
                   help='Local topology defaults file')
   parser.add_argument('-d','--device', dest='device', action='store', help='Default device type')
   parser.add_argument('-p','--provider', dest='provider', action='store',help='Override virtualization provider')
   parser.add_argument('-s','--set',dest='settings', action='append',help='Additional parameters added to topology file')
   return parser
 
+#
+# Common file/directory cleanup routine, used by collect/clab/down
+#
+
+def fs_cleanup(filelist: typing.List[str], verbose: bool = False) -> None:
+  for fname in filelist:
+    if os.path.isdir(fname):
+      if verbose:
+        print(f"... removing directory tree {fname}")
+      try:
+        shutil.rmtree(fname)
+      except Exception as ex:
+        common.fatal(f"Cannot clean up directory {fname}: {ex}")
+    elif os.path.exists(fname):
+      if verbose:
+        print(f"... removing {fname}")
+      try:
+        os.remove(fname)
+      except Exception as ex:
+        common.fatal(f"Cannot remove {fname}: {ex}")
+
 # Common topology loader (used by create and down)
 
 def load_topology(args: argparse.Namespace) -> Box:
@@ -49,6 +74,23 @@ def load_topology(args: argparse.Namespace) -> Box:
   common.exit_on_error()
   return topology
 
+# Snapshot-or-topology loader (used by down)
+
+def load_snapshot_or_topology(args: argparse.Namespace) -> typing.Optional[Box]:
+  common.set_logging_flags(args)
+  if args.device or args.provider or args.settings:     # If we have -d, -p or -s flag
+    if not args.topology:                               # ... then the user wants to use the topology file
+      args.topology = 'topology.yml'                    # ... so let's set the default value if needed
+
+  if args.topology:
+    topology = load_topology(args)
+    augment.main.transform(topology)
+    common.exit_on_error()
+    return topology
+  else:
+    args.snapshot = args.snapshot or 'netlab.snapshot.yml'
+    return read_topology.read_yaml(filename=args.snapshot)
+
 #
 # Main command dispatcher
 #
