@@ -20,6 +20,9 @@ QUIET : bool = False
 RAISE_ON_ERROR : bool = False
 WARNING : bool = False
 
+AF_LIST = ['ipv4','ipv6']
+BGP_SESSIONS = ['ibgp','ebgp']
+
 err_count : int = 0
 netsim_package_path = os.path.abspath(os.path.dirname(__file__))
 
@@ -120,10 +123,10 @@ def print_verbose(t: typing.Any) -> None:
 def set_logging_flags(args: argparse.Namespace) -> None:
   global VERBOSE, LOGGING, DEBUG, QUIET, WARNING, RAISE_ON_ERROR
   
-  if args.verbose:
+  if 'verbose' in args and args.verbose:
     VERBOSE = args.verbose
 
-  if args.logging:
+  if 'logging' in args and args.logging:
     LOGGING = True
 
   if 'debug' in args and args.debug:
@@ -167,75 +170,3 @@ def set_flag(
     'raise_on_error': RAISE_ON_ERROR,
     'warning': WARNING
   }
-
-#
-# Change all NULL values in a nested dictionary structure to empty strings
-# to make them nicer in YAML printouts
-#
-def null_to_string(d: typing.Dict) -> None:
-  for k in d.keys():
-    if isinstance(d[k],dict):
-      null_to_string(d[k])
-    elif d[k] is None:
-      d[k] = ""
-
-#
-# must_be_list: make sure a dictionary value is a list. Convert scalar values
-#   to list if needed, report an error otherwise.
-#
-# Input arguments:
-#   parent - the parent dictionary of the attribute we want to listify
-#            (a pointer to the element would be even better, but Python)
-#   key    - the parent dictionary key
-#   path   - path of the parent dictionary that would help the user identify
-#            where the problem is
-#
-# Sample use: make sure the 'config' attribute of a node is list
-#
-#    must_be_list(node,'config',f'nodes.{node.name}')
-#
-def must_be_list(parent: Box, key: str, path: str) -> typing.Optional[list]:
-  if not key in parent:
-    parent[key] = []
-    return parent[key]
-
-  if isinstance(parent[key],list):
-    return parent[key]
-
-  if isinstance(parent[key],(str,int,float,bool)):
-    parent[key] = [ parent[key] ]
-    return parent[key]
-
-  wrong_type = "dictionary" if isinstance(parent[key],dict) else str(type(parent[key]))
-  error(f'attribute {path}.{key} must be a scalar or a list, found {wrong_type}',IncorrectType)
-  return None
-
-#
-# Set a dictionary value specified by a list of keys
-#
-def set_dots(b : dict,k_list : list,v : typing.Any) -> None:
-  if len(k_list) <= 1:
-    b[k_list[0]] = v
-    return
-  if not k_list[0] in b:
-    b[k_list[0]] = {}
-  elif b[k_list[0]] is None:
-    b[k_list[0]] = {}
-  set_dots(b[k_list[0]],k_list[1:],v)
-
-#
-# Change dotted dictionary keys into nested dictionaries
-#
-def unroll_dots(b : typing.Any) -> None:
-  if isinstance(b,dict):
-    for k in list(b.keys()):
-      unroll_dots(b[k])
-      if isinstance(k,str) and ('.' in k):
-        v = b[k]
-        del b[k]     # If you're using Box with box_dots parameter
-        set_dots(b,k.split('.'),v)
-  elif isinstance(b,list):
-    for v in b:
-      unroll_dots(v)
-  else:
-    return
