@@ -5,9 +5,10 @@ import typing
 
 import yaml
 import os
-from box import Box
+from box import Box,BoxList
 
 from .. import common
+from .. import data
 from ..augment import topology
 
 from . import _TopologyOutput
@@ -23,7 +24,7 @@ class YAML(_TopologyOutput):
       if len(self.filenames) > 1:
         common.error('Extra output filename(s) ignored: %s' % str(self.filenames[1:]),common.IncorrectValue,modname)
 
-    cleantopo = topology.cleanup_topology(topo)
+    cleantopo: typing.Any = topology.cleanup_topology(topo)
     output = common.open_output_file(outfile)
 
     for fmt in self.format:
@@ -31,8 +32,12 @@ class YAML(_TopologyOutput):
         cleantopo.pop('defaults')
       elif fmt == 'noaddr':
         cleantopo.pop('addressing')
-      elif fmt in cleantopo:
-        cleantopo = cleantopo[fmt]
+      elif data.get_from_box(cleantopo,fmt):
+        result = data.get_from_box(cleantopo,fmt)
+        if not isinstance(result,Box) and not isinstance(result,BoxList):
+          common.fatal(f'Selecting {fmt} did not result in a usable dictionary, aborting')
+          return
+        cleantopo = result
         break
       else:
         common.error('Invalid format modifier %s' % fmt,common.IncorrectValue,modname)
